@@ -30,9 +30,11 @@ from neutron_lib.api.definitions import dns
 from neutron_lib.api.definitions import dns_domain_ports
 from neutron_lib.api.definitions import dvr
 from neutron_lib.api.definitions import empty_string_filtering
+from neutron_lib.api.definitions import expose_port_forwarding_in_fip
 from neutron_lib.api.definitions import external_net
 from neutron_lib.api.definitions import extra_dhcp_opt
 from neutron_lib.api.definitions import extraroute
+from neutron_lib.api.definitions import filter_validation
 from neutron_lib.api.definitions import fip64
 from neutron_lib.api.definitions import fip_port_details
 from neutron_lib.api.definitions import firewall
@@ -61,14 +63,18 @@ from neutron_lib.api.definitions import network_mtu_writable
 from neutron_lib.api.definitions import pagination
 from neutron_lib.api.definitions import port
 from neutron_lib.api.definitions import port_mac_address_regenerate
+from neutron_lib.api.definitions import port_resource_request
 from neutron_lib.api.definitions import port_security
 from neutron_lib.api.definitions import portbindings
 from neutron_lib.api.definitions import portbindings_extended
+from neutron_lib.api.definitions import project_default_networks
 from neutron_lib.api.definitions import project_id
 from neutron_lib.api.definitions import provider_net
 from neutron_lib.api.definitions import qos
 from neutron_lib.api.definitions import qos_bw_limit_direction
+from neutron_lib.api.definitions import qos_bw_minimum_ingress
 from neutron_lib.api.definitions import qos_default
+from neutron_lib.api.definitions import qos_gateway_ip
 from neutron_lib.api.definitions import qos_rule_type_details
 from neutron_lib.api.definitions import revisionifmatch
 from neutron_lib.api.definitions import router_availability_zone
@@ -76,8 +82,10 @@ from neutron_lib.api.definitions import router_interface_fip
 from neutron_lib.api.definitions import routerservicetype
 from neutron_lib.api.definitions import security_groups_port_filtering
 from neutron_lib.api.definitions import segment
+from neutron_lib.api.definitions import segments_peer_subnet_host_routes
 from neutron_lib.api.definitions import servicetype
 from neutron_lib.api.definitions import sfc
+from neutron_lib.api.definitions import sort_key_validation
 from neutron_lib.api.definitions import sorting
 from neutron_lib.api.definitions import standard_attr_segment
 from neutron_lib.api.definitions import subnet
@@ -114,9 +122,11 @@ _ALL_API_DEFINITIONS = {
     dns_domain_ports,
     dvr,
     empty_string_filtering,
+    expose_port_forwarding_in_fip,
     external_net,
     extra_dhcp_opt,
     extraroute,
+    filter_validation,
     fip64,
     firewall,
     firewall_v2,
@@ -145,14 +155,18 @@ _ALL_API_DEFINITIONS = {
     pagination,
     port,
     port_mac_address_regenerate,
+    port_resource_request,
     port_security,
     portbindings,
     portbindings_extended,
+    project_default_networks,
     project_id,
     provider_net,
     qos,
     qos_bw_limit_direction,
+    qos_bw_minimum_ingress,
     qos_default,
+    qos_gateway_ip,
     qos_rule_type_details,
     revisionifmatch,
     router_availability_zone,
@@ -160,8 +174,10 @@ _ALL_API_DEFINITIONS = {
     routerservicetype,
     security_groups_port_filtering,
     segment,
+    segments_peer_subnet_host_routes,
     servicetype,
     sfc,
+    sort_key_validation,
     sorting,
     standard_attr_segment,
     subnet,
