@@ -41,6 +41,7 @@ KNOWN_ATTRIBUTES = (
     'prefixes',
     'prefixlen',
     'project_id',
+    'qos_policy_id',
     constants.SHARED,
     'status',
     'subnets',
@@ -81,16 +82,19 @@ KNOWN_EXTENSIONS = (
     'availability_zone',
     'binding',
     'data-plane-status',
+    'project-default-networks',
     'default-subnetpools',
     'dhcp_agent_scheduler',
     'dns-domain-ports',
     'dns-integration',
     'dvr',
     'empty-string-filtering',
+    'expose-port-forwarding-in-fip',
     'ext-gw-mode',
     'external-net',
     'extra_dhcp_opt',
     'extraroute',
+    'filter-validation',
     'fip-port-details',
     'flavors',
     'floating-ip-port-forwarding',
@@ -105,10 +109,12 @@ KNOWN_EXTENSIONS = (
     'network-ip-availability',
     'network_availability_zone',
     'pagination',
+    'port-resource-request',
     'port-security',
     'project-id',
     'provider',
     'qos',
+    'qos-gateway-ip',
     'quotas',
     'rbac-policies',
     'router',
@@ -116,9 +122,11 @@ KNOWN_EXTENSIONS = (
     'security-group',
     'segment',
     'service-type',
+    'sort-key-validation',
     'sorting',
     'standard-attr-description',
     'standard-attr-revisions',
+    'standard-attr-segment',
     'standard-attr-timestamp',
     'subnet_allocation',
     'subnet_onboard',
